@@ -3,7 +3,7 @@
  * $Id: bufstr.h,v 1.85 2000/11/18 12:58:19 root Exp $
  *
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -69,6 +69,10 @@ class BufStr
       }
       m_buf = (char *)realloc(m_buf,m_size);
     }
+    int size() const
+    {
+      return m_size;
+    }
     char *data() const
     {
       return m_buf;
@@ -89,6 +93,13 @@ class BufStr
     { 
       return m_writeOffset; 
     }
+    void dropFromStart(uint bytes)
+    {
+      if (bytes>m_size) bytes=m_size;
+      if (bytes>0) qmemmove(m_buf,m_buf+bytes,m_size-bytes);
+      m_size-=bytes;
+      m_writeOffset-=bytes;
+    }
   private:
     void makeRoomFor(uint size)
     {
