@@ -79,11 +79,14 @@ class ClassDef : public Definition
      *                   generates based on the compound type & name.
      *  \param isSymbol  If TRUE this class name is added as a publicly 
      *                   visible (and referencable) symbol.
+     *  \param isJavaEnum If TRUE this class is actually a Java enum.
+     *                    I didn't add this to CompoundType to avoid having
+     *                    to adapt all translators.
      */
     ClassDef(const char *fileName,int startLine,
              const char *name,CompoundType ct,
              const char *ref=0,const char *fName=0,
-             bool isSymbol=TRUE);
+             bool isSymbol=TRUE,bool isJavaEnum=FALSE);
     /*! Destroys a compound definition. */
    ~ClassDef();
 
@@ -95,8 +98,7 @@ class ClassDef : public Definition
     DefType definitionType() const { return TypeClass; }
 
     /*! Returns the unique base name (without extension) of the class's file on disk */
-    QCString getOutputFileBase() const; 
-    QCString getXmlOutputFileBase() const;
+    QCString getOutputFileBase() const;
     QCString getInstanceOutputFileBase() const; 
     QCString getFileBase() const;
 
@@ -113,7 +115,7 @@ class ClassDef : public Definition
     bool isLocal() const;
 
     /*! returns the classes nested into this class */
-    ClassSDict *getInnerClasses();
+    ClassSDict *getClassSDict();
 
     /*! returns TRUE if this class has documentation */
     bool hasDocumentation() const;
@@ -265,7 +267,16 @@ class ClassDef : public Definition
     bool isUsedOnly() const;
 
     QCString anchor() const;
-    bool isEmbeddedInGroupDocs() const;
+    bool isEmbeddedInOuterScope() const;
+
+    bool isSimple() const;
+
+    const ClassList *taggedInnerClasses() const;
+    ClassDef *tagLessReference() const;
+
+    MemberDef *isSmartPointer() const;
+
+    bool isJavaEnum() const;
 
     //-----------------------------------------------------------------------------------
     // --- setters ----
@@ -286,10 +297,9 @@ class ClassDef : public Definition
     void addInnerCompound(Definition *d);
     ClassDef *insertTemplateInstance(const QCString &fileName,int startLine,
                                 const QCString &templSpec,bool &freshInstance);
-    void addUsedClass(ClassDef *cd,const char *accessName);
-    void addUsedByClass(ClassDef *cd,const char *accessName);
+    void addUsedClass(ClassDef *cd,const char *accessName,Protection prot);
+    void addUsedByClass(ClassDef *cd,const char *accessName,Protection prot);
     void setIsStatic(bool b);
-    void setLanguage(SrcLangExt lang);
     void setCompoundType(CompoundType t);
     void setClassName(const char *name);
 
@@ -302,6 +312,9 @@ class ClassDef : public Definition
     void setCategoryOf(ClassDef *cd);
     void setUsedOnly(bool b);
 
+    void addTaggedInnerClass(ClassDef *cd);
+    void setTagLessReference(ClassDef *cd);
+
     //-----------------------------------------------------------------------------------
     // --- actions ----
     //-----------------------------------------------------------------------------------
@@ -324,6 +337,7 @@ class ClassDef : public Definition
     void writeInlineDocumentation(OutputList &ol);
     void writeDeclarationLink(OutputList &ol,bool &found,
                               const char *header,bool localNames);
+    void removeMemberFromLists(MemberDef *md);
     
     bool visited;
 
@@ -343,6 +357,7 @@ class ClassDef : public Definition
     void writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,const QCString &title,
                                  const char *subTitle=0,bool showInline=FALSE);
     void writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,const QCString &title,bool showInline=FALSE);
+    void writeSimpleMemberDocumentation(OutputList &ol,MemberList::ListType lt);
     void writePlainMemberDeclaration(OutputList &ol,MemberList::ListType lt,bool inGroup);
     void writeBriefDescription(OutputList &ol,bool exampleFlag);
     void writeDetailedDescription(OutputList &ol,const QCString &pageType,bool exampleFlag,
@@ -353,6 +368,7 @@ class ClassDef : public Definition
     void writeCollaborationGraph(OutputList &ol);
     void writeMemberGroups(OutputList &ol,bool showInline=FALSE);
     void writeNestedClasses(OutputList &ol,const QCString &title);
+    void writeInlineClasses(OutputList &ol);
     void startMemberDeclarations(OutputList &ol);
     void endMemberDeclarations(OutputList &ol);
     void startMemberDocumentation(OutputList &ol);
