@@ -59,7 +59,7 @@
 "    <xsd:attribute name=\"ambiguityscope\" type=\"xsd:string\" />\n"
 "  </xsd:complexType>\n"
 "\n"
-"  <xsd:complexType name=\"compoundRefType\" mixed=\"true\">\n"
+"  <xsd:complexType name=\"compoundRefType\">\n"
 "    <xsd:simpleContent>\n"
 "      <xsd:extension base=\"xsd:string\">\n"
 "        <xsd:attribute name=\"refid\" type=\"xsd:string\" use=\"optional\" />\n"
@@ -69,7 +69,7 @@
 "    </xsd:simpleContent>\n"
 "  </xsd:complexType>\n"
 "\n"
-"  <xsd:complexType name=\"reimplementType\" mixed=\"true\">\n"
+"  <xsd:complexType name=\"reimplementType\">\n"
 "    <xsd:simpleContent>\n"
 "      <xsd:extension base=\"xsd:string\">\n"
 "        <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
@@ -77,7 +77,7 @@
 "    </xsd:simpleContent>\n"
 "  </xsd:complexType>\n"
 "\n"
-"  <xsd:complexType name=\"incType\" mixed=\"true\">\n"
+"  <xsd:complexType name=\"incType\">\n"
 "    <xsd:simpleContent>\n"
 "      <xsd:extension base=\"xsd:string\">\n"
 "        <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
@@ -86,7 +86,7 @@
 "    </xsd:simpleContent>\n"
 "  </xsd:complexType>\n"
 "\n"
-"  <xsd:complexType name=\"refType\" mixed=\"true\">\n"
+"  <xsd:complexType name=\"refType\">\n"
 "    <xsd:simpleContent>\n"
 "      <xsd:extension base=\"xsd:string\">\n"
 "        <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
@@ -95,12 +95,13 @@
 "    </xsd:simpleContent>\n"
 "  </xsd:complexType>\n"
 "\n"
-"  <xsd:complexType name=\"refTextType\" mixed=\"true\">\n"
+"  <xsd:complexType name=\"refTextType\">\n"
 "    <xsd:simpleContent>\n"
 "      <xsd:extension base=\"xsd:string\">\n"
 "       <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
 "       <xsd:attribute name=\"kindref\" type=\"DoxRefKind\" />\n"
-"       <xsd:attribute name=\"external\" type=\"xsd:string\" />\n"
+"       <xsd:attribute name=\"external\" type=\"xsd:string\" use=\"optional\"/>\n"
+"       <xsd:attribute name=\"tooltip\" type=\"xsd:string\" use=\"optional\"/>\n"
 "      </xsd:extension>\n"
 "    </xsd:simpleContent>\n"
 "  </xsd:complexType>\n"
@@ -464,7 +465,10 @@
 "  <xsd:complexType name=\"docSimpleSectType\">\n"
 "    <xsd:sequence>\n"
 "      <xsd:element name=\"title\" type=\"docTitleType\" minOccurs=\"0\" />\n"
-"      <xsd:element name=\"para\" type=\"docParaType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
+"      <xsd:sequence minOccurs=\"0\" maxOccurs=\"unbounded\">\n"
+"        <xsd:element name=\"para\" type=\"docParaType\" minOccurs=\"1\" maxOccurs=\"unbounded\" />\n"
+"        <xsd:element name=\"simplesectsep\" type=\"docEmptyType\" minOccurs=\"0\"/>\n"
+"      </xsd:sequence>\n"
 "    </xsd:sequence>\n"
 "    <xsd:attribute name=\"kind\" type=\"DoxSimpleSectKind\" />\n"
 "  </xsd:complexType>\n"
@@ -573,10 +577,17 @@
 "\n"
 "  <xsd:complexType name=\"docParamNameList\">\n"
 "    <xsd:sequence>\n"
+"      <xsd:element name=\"parametertype\" type=\"docParamType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"parametername\" type=\"docParamName\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "    </xsd:sequence>\n"
 "  </xsd:complexType>\n"
 "\n"
+"  <xsd:complexType name=\"docParamType\" mixed=\"true\">\n"
+"    <xsd:sequence>\n"
+"      <xsd:element name=\"ref\" type=\"refTextType\" minOccurs=\"0\" maxOccurs=\"1\" />\n"
+"    </xsd:sequence>\n"
+"  </xsd:complexType>\n"
+"\n"
 "  <xsd:complexType name=\"docParamName\" mixed=\"true\">\n"
 "    <xsd:sequence>\n"
 "      <xsd:element name=\"ref\" type=\"refTextType\" minOccurs=\"0\" maxOccurs=\"1\" />\n"
@@ -753,6 +764,7 @@
 "      <xsd:enumeration value=\"warning\" />\n"
 "      <xsd:enumeration value=\"pre\" />\n"
 "      <xsd:enumeration value=\"post\" />\n"
+"      <xsd:enumeration value=\"copyright\" />\n"
 "      <xsd:enumeration value=\"invariant\" />\n"
 "      <xsd:enumeration value=\"remark\" />\n"
 "      <xsd:enumeration value=\"attention\" />\n"
