@@ -478,10 +478,12 @@ public:
         bool needs_entry(false);
         bool brief(false);
         Protection prot(Public);
+        int lineNr = lineNumber();
 
         while (parseCommentBlock(m_parser,
                                  m_currentEntry,
-                                 text, m_fileName.utf8().data(), lineNumber(),
+                                 text, m_fileName.utf8().data(), 
+                                 lineNr,
                                  brief, m_currentComment->isJavaStyle,
                                  false,
                                  prot,
@@ -595,8 +597,8 @@ private:
         {
             type = attributes.value(type_idx);
 
-            QRegExp reg_exp(QString("(a?[ybnqiuxdtsogv]|a[{]sv[}])"));
-            if (reg_exp.match(type))
+            QRegExp reg_exp(QCString("(a?[ybnqiuxdtsogv]|a[{]sv[}])"));
+            if (reg_exp.match(type.data()))
             { return type; }
 
             DOC_ERROR(QString("Unnamed complex D-Bus type \"%1\" found.").arg(type));
@@ -664,7 +666,7 @@ private:
         entry->protection = Public ;
         entry->virt       = Normal;
         entry->stat       = false;
-        entry->objc       = false;
+        entry->lang       = SrcLangExt_XML;
         entry->spec       = 0;
 
         entry->fileName  = m_fileName;
@@ -844,6 +846,7 @@ void DBusXMLScanner::parseInput(const char * fileName,
                                 const char * /* fileBuf */,
                                 Entry * root)
 {
+    err("Note that the dbusxml parser seems to be broken :-(\nPlease help me to fix it!\n");
     QFile inputFile(fileName);
 
     QXmlInputSource inputSource(inputFile);
@@ -877,7 +880,8 @@ void DBusXMLScanner::parseCode(CodeOutputInterface & /* codeOutIntf */,
                                int /* startLine */,
                                int /* endLine */,
                                bool /* inlineFragment */,
-                               MemberDef * /* memberDef */)
+                               MemberDef * /* memberDef */,
+                               bool /*showLineNumbers*/)
 { }
 
 void DBusXMLScanner::resetCodeParserState()
