@@ -2,7 +2,7 @@
  *
  * $Id: definition.h,v 1.21 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -24,6 +24,7 @@
 #include <sys/types.h>
 
 #include "lockingptr.h"
+#include "util.h"
 
 class FileDef;
 class OutputList;
@@ -131,6 +132,9 @@ class Definition : public DefinitionIntf, public LockableObj
      */
     virtual QCString getOutputFileBase() const = 0;
 
+    /*! Returns the anchor within a page where this item can be found */
+    virtual QCString anchor() const = 0;
+
     /*! Returns the name of the source listing of this file. */
     virtual QCString getSourceFileBase() const { ASSERT(0); return "NULL"; }
 
@@ -178,7 +182,7 @@ class Definition : public DefinitionIntf, public LockableObj
     QCString getDefFileExtension() const;
 
     /*! returns the line number at which the definition was found */
-    int getDefLine() const;
+    int getDefLine() const { return m_defLine; }
 
     /*! Returns TRUE iff the definition is documented 
      *  (which could be generated documentation) 
@@ -240,6 +244,9 @@ class Definition : public DefinitionIntf, public LockableObj
      */
     FileDef *getBodyDef();
 
+    /** Returns the programming language this definition was written in. */
+    SrcLangExt getLanguage() const;
+
     LockingPtr<GroupList> partOfGroups() const;
 
     LockingPtr< QList<ListItemInfo> > xrefListItems() const;
@@ -250,6 +257,7 @@ class Definition : public DefinitionIntf, public LockableObj
     LockingPtr<MemberSDict> getReferencesMembers() const;
     LockingPtr<MemberSDict> getReferencedByMembers() const;
 
+
     //-----------------------------------------------------------------------------------
     // ----  setters -----
     //-----------------------------------------------------------------------------------
@@ -258,18 +266,18 @@ class Definition : public DefinitionIntf, public LockableObj
     void setName(const char *name);
 
     /*! Sets the documentation of this definition to \a d. */
-    void setDocumentation(const char *d,const char *docFile,int docLine,bool stripWhiteSpace=TRUE);
+    virtual void setDocumentation(const char *d,const char *docFile,int docLine,bool stripWhiteSpace=TRUE);
 
     /*! Sets the brief description of this definition to \a b.
      *  A dot is added to the sentence if not available.
      */
-    void setBriefDescription(const char *b,const char *briefFile,int briefLine);
+    virtual void setBriefDescription(const char *b,const char *briefFile,int briefLine);
 
     /*! Set the documentation that was found inside the body of an item.
      *  If there was already some documentation set, the new documentation
      *  will be appended.
      */
-    void setInbodyDocumentation(const char *d,const char *docFile,int docLine);
+    virtual void setInbodyDocumentation(const char *d,const char *docFile,int docLine);
 
     /*! Sets the tag file id via which this definition was imported. */
     void setReference(const char *r);
@@ -290,9 +298,10 @@ class Definition : public DefinitionIntf, public LockableObj
     virtual void addInnerCompound(Definition *d);
     virtual void setOuterScope(Definition *d);
 
-    void setHidden(bool b);
+    virtual void setHidden(bool b);
 
     void setArtificial(bool b);
+    void setLanguage(SrcLangExt lang);
 
     //-----------------------------------------------------------------------------------
     // --- actions ----
@@ -305,7 +314,7 @@ class Definition : public DefinitionIntf, public LockableObj
     void writeSourceReffedBy(OutputList &ol,const char *scopeName);
     void makePartOfGroup(GroupDef *gd);
     void writePathFragment(OutputList &ol) const;
-    void writeNavigationPath(OutputList &ol) const;
+    void writeNavigationPath(OutputList &ol,bool showSearchInfo=TRUE) const;
     virtual void writeQuickMemberLinks(OutputList &,MemberDef *) const {}
     virtual void writeSummaryLinks(OutputList &) {}
     QCString pathFragment() const;
@@ -342,7 +351,7 @@ class Definition : public DefinitionIntf, public LockableObj
     QCString m_name;
     bool m_isSymbol;
     QCString m_symbolName;
-
+    int m_defLine;
 };
 
 class DefinitionList : public QList<Definition>, public DefinitionIntf
