@@ -3,7 +3,7 @@
  * $Id: diagram.cpp,v 1.30 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -164,7 +164,17 @@ static void writeMapArea(FTextStream &t,ClassDef *cd,QCString relPath,
     }
     t << "href=\"";
     t << externalRef(relPath,ref,TRUE);
-    t << cd->getOutputFileBase() << Doxygen::htmlFileExtension << "\" ";
+    t << cd->getOutputFileBase() << Doxygen::htmlFileExtension;
+    if (!cd->anchor().isEmpty())
+    {
+      t << "#" << cd->anchor();
+    }
+    t << "\" ";
+    QCString tooltip = cd->briefDescriptionAsTooltip();
+    if (!tooltip.isEmpty())
+    {
+      t << "title=\"" << tooltip << "\" ";
+    }
     t << "alt=\"" << convertToXML(cd->displayName()); 
     t << "\" shape=\"rect\" coords=\"" << x << "," << y << ",";
     t << (x+w) << "," << (y+h) << "\"/>" << endl;
@@ -349,7 +359,7 @@ bool TreeDiagram::layoutTree(DiagramItem *root,int r)
     DiagramItem *di=dil->first();
     while (di && !moved && !di->isInList())
     {
-      moved = moved || layoutTree(di,r+1);
+      moved = layoutTree(di,r+1);
       di=dil->next();
     }
   }
