@@ -3,7 +3,7 @@
 "body, table, div, p, dl {\n"
 "	font-family: Lucida Grande, Verdana, Geneva, Arial, sans-serif;\n"
 "	font-size: 13px;\n"
-"	line-height: 1.5;\n"
+"	line-height: 1.3;\n"
 "}\n"
 "\n"
 "/* @group Heading Levels */\n"
@@ -122,11 +122,11 @@
 "a.elRef {\n"
 "}\n"
 "\n"
-"a.code {\n"
+"a.code, a.code:visited {\n"
 "	color: #4665A2; \n"
 "}\n"
 "\n"
-"a.codeRef {\n"
+"a.codeRef, a.codeRef:visited {\n"
 "	color: #4665A2; \n"
 "}\n"
 "\n"
