@@ -2,7 +2,7 @@
  *
  * $Id: filedef.h,v 1.32 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -42,12 +42,13 @@ class DirDef;
 
 struct IncludeInfo
 {
-  IncludeInfo() { fileDef=0; local=FALSE; }
+  IncludeInfo() { fileDef=0; local=FALSE; indirect=FALSE; }
   ~IncludeInfo() {}
   FileDef *fileDef;
   QCString includeName;
   bool local;
   bool imported;
+  bool indirect;
 };
 
 /*! \class FileDef filedef.h
@@ -87,6 +88,8 @@ class FileDef : public Definition
     
     QCString getOutputFileBase() const 
     { return convertNameToFile(diskname); }
+    QCString anchor() const
+    { return QCString(); }
 
     QCString getFileBase() const
     { return diskname; }
@@ -124,13 +127,13 @@ class FileDef : public Definition
     }
     bool isIncluded(const QCString &name) const;
 
-    bool isJava() const { return m_isJava; }
+    //bool isJava() const { return m_isJava; }
+    //bool isCSharp() const { return m_isCSharp; }
 
-    void writeDetailedDocumentation(OutputList &ol);
     void writeDocumentation(OutputList &ol);
-    void writeMemberDocumentation(OutputList &ol);
     void writeMemberPages(OutputList &ol);
     void writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const;
+    void writeSummaryLinks(OutputList &ol);
 
     void writeSource(OutputList &ol);
     void parseSource();
@@ -153,8 +156,9 @@ class FileDef : public Definition
     void combineUsingRelations();
 
     bool generateSourceFile() const;
+    void sortMemberLists();
 
-    void addIncludeDependency(FileDef *fd,const char *incName,bool local,bool imported);
+    void addIncludeDependency(FileDef *fd,const char *incName,bool local,bool imported,bool indirect);
     void addIncludedByDependency(FileDef *fd,const char *incName,bool local,bool imported);
     QList<IncludeInfo> *includeFileList() const { return includeList; }
     QList<IncludeInfo> *includedByFileList() const { return includedByList; }
@@ -166,6 +170,8 @@ class FileDef : public Definition
 
     void addListReferences();
     bool isDocumentationFile() const;
+    //bool includes(FileDef *incFile,QDict<FileDef> *includedFiles) const;
+    //bool includesByName(const QCString &name) const;
 
     MemberList *getMemberList(MemberList::ListType lt) const;
     const QList<MemberList> &getMemberLists() const { return m_memberLists; }
@@ -188,6 +194,21 @@ class FileDef : public Definition
     void addMemberToList(MemberList::ListType lt,MemberDef *md);
     void writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,const QCString &title);
     void writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,const QCString &title);
+    void writeIncludeFiles(OutputList &ol);
+    void writeIncludeGraph(OutputList &ol);
+    void writeIncludedByGraph(OutputList &ol);
+    void writeMemberGroups(OutputList &ol);
+    void writeAuthorSection(OutputList &ol);
+    void writeSourceLink(OutputList &ol);
+    void writeNamespaceDeclarations(OutputList &ol,const QCString &title);
+    void writeClassDeclarations(OutputList &ol,const QCString &title);
+    void writeInlineClasses(OutputList &ol);
+    void startMemberDeclarations(OutputList &ol);
+    void endMemberDeclarations(OutputList &ol);
+    void startMemberDocumentation(OutputList &ol);
+    void endMemberDocumentation(OutputList &ol);
+    void writeDetailedDescription(OutputList &ol,const QCString &title);
+    void writeBriefDescription(OutputList &ol);
 
     QDict<IncludeInfo>   *includeDict;
     QList<IncludeInfo>   *includeList;
@@ -203,7 +224,8 @@ class FileDef : public Definition
     QIntDict<Definition> *srcDefDict;
     QIntDict<MemberDef>  *srcMemberDict;
     bool                  isSource;
-    bool                  m_isJava;
+    //bool                  m_isJava;
+    //bool                  m_isCSharp;
     QCString              fileVersion;
     PackageDef           *package;
     DirDef               *dir;
