@@ -2,7 +2,7 @@
  *
  * $Id: groupdef.cpp,v 1.29 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -131,8 +131,9 @@ void GroupDef::findSectionsInDocumentation()
 
 void GroupDef::addFile(const FileDef *def)
 {
+  static bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
   if (def->isHidden()) return;
-  if (Config_getBool("SORT_BRIEF_DOCS"))
+  if (sortBriefDocs)
     fileList->inSort(def);
   else
     fileList->append(def);
@@ -140,13 +141,46 @@ void GroupDef::addFile(const FileDef *def)
 
 bool GroupDef::addClass(const ClassDef *cd)
 {
+  static bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
   if (cd->isHidden()) return FALSE;
-  if (classSDict->find(cd->name())==0)
+  if (classSDict->find(cd->qualifiedName())==0)
   {
-    if (Config_getBool("SORT_BRIEF_DOCS"))
-      classSDict->inSort(cd->name(),cd);
+    QCString qn = cd->qualifiedName();
+    //printf("--- addClass %s sort=%d\n",qn.data(),sortBriefDocs);
+    if (sortBriefDocs)
+    {
+      classSDict->inSort(cd->qualifiedName(),cd);
+    }
     else
-      classSDict->append(cd->name(),cd);
+    {
+      int i=qn.findRev("::");
+      if (i==-1) i=qn.find('.');
+      bool found=FALSE;
+      //printf("i=%d\n",i);
+      if (i!=-1)
+      {
+        // add nested classes (e.g. A::B, A::C) after their parent (A) in 
+        // order of insertion
+        QCString scope = qn.left(i);
+        int j=classSDict->findAt(scope);
+        if (j!=-1)
+        {
+          while (j<(int)classSDict->count() && 
+              classSDict->at(j)->qualifiedName().left(i)==scope)
+          {
+            //printf("skipping over %s\n",classSDict->at(j)->qualifiedName().data());
+            j++;
+          }
+          //printf("Found scope at index %d\n",j);
+          classSDict->insertAt(j,cd->qualifiedName(),cd);
+          found=TRUE;
+        }
+      }
+      if (!found) // no insertion point found -> just append
+      {
+        classSDict->append(cd->qualifiedName(),cd);
+      }
+    }
     return TRUE;
   }
   return FALSE;
@@ -154,10 +188,11 @@ bool GroupDef::addClass(const ClassDef *cd)
 
 bool GroupDef::addNamespace(const NamespaceDef *def)
 {
+  static bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
   if (def->isHidden()) return FALSE;
   if (namespaceSDict->find(def->name())==0)
   {
-    if (Config_getBool("SORT_BRIEF_DOCS"))
+    if (sortBriefDocs)
       namespaceSDict->inSort(def->name(),def);  
     else
       namespaceSDict->append(def->name(),def);
@@ -231,15 +266,20 @@ bool GroupDef::insertMember(MemberDef *md,bool docOnly)
            (srcMd->getOuterScope()->definitionType()==Definition::TypeFile &&
             md->getOuterScope()->definitionType()==Definition::TypeFile); 
 
-      LockingPtr<ArgumentList> srcMdAl = srcMd->argumentList();
-      LockingPtr<ArgumentList> mdAl    = md->argumentList();
+      LockingPtr<ArgumentList> srcMdAl  = srcMd->argumentList();
+      LockingPtr<ArgumentList> mdAl     = md->argumentList();
+      LockingPtr<ArgumentList> tSrcMdAl = srcMd->templateArguments();
+      LockingPtr<ArgumentList> tMdAl    = md->templateArguments();
       
-      if (srcMd->isFunction() && md->isFunction() && 
+      if (srcMd->isFunction() && md->isFunction() && // both are a function
+          ((tSrcMdAl.pointer()==0 && tMdAl.pointer()==0) || 
+           (tSrcMdAl.pointer()!=0 && tMdAl.pointer()!=0 && tSrcMdAl->count()==tMdAl->count())
+          ) &&       // same number of template arguments
           matchArguments2(srcMd->getOuterScope(),srcMd->getFileDef(),srcMdAl.pointer(),
                           md->getOuterScope(),md->getFileDef(),mdAl.pointer(),
                           TRUE
-                         ) &&
-          sameScope
+                         ) && // matching parameters
+          sameScope // both are found in the same scope
          )
       {
         if (srcMd->getGroupAlias()==0) 
@@ -508,7 +548,7 @@ void GroupDef::writeDetailedDescription(OutputList &ol,const QCString &title)
       ol.writeRuler();
       ol.pushGeneratorState();
       ol.disableAllBut(OutputGenerator::Html);
-        ol.writeAnchor(0,"_details");
+        ol.writeAnchor(0,"details");
       ol.popGeneratorState();
       ol.startGroupHeader();
       ol.parseText(title);
@@ -550,7 +590,7 @@ void GroupDef::writeDetailedDescription(OutputList &ol,const QCString &title)
 
 void GroupDef::writeBriefDescription(OutputList &ol)
 {
-  if (!briefDescription().isEmpty())
+  if (!briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
   {
     ol.startParagraph();
     ol.parseDoc(briefFile(),briefLine(),this,0,
@@ -565,16 +605,11 @@ void GroupDef::writeBriefDescription(OutputList &ol)
        )
     {
       ol.disableAllBut(OutputGenerator::Html);
-      ol.startTextLink(0,"_details");
+      ol.startTextLink(0,"details");
       ol.parseText(theTranslator->trMore());
       ol.endTextLink();
     }
     ol.popGeneratorState();
-
-    //ol.pushGeneratorState();
-    //ol.disable(OutputGenerator::RTF);
-    //ol.newParagraph();
-    //ol.popGeneratorState();
     ol.endParagraph();
   }
 }
@@ -589,11 +624,11 @@ void GroupDef::writeGroupGraph(OutputList &ol)
       msg("Generating dependency graph for group %s\n",qualifiedName().data());
       ol.pushGeneratorState();
       ol.disable(OutputGenerator::Man);
-      ol.startParagraph();
+      //ol.startParagraph();
       ol.startGroupCollaboration();
       ol.parseText(theTranslator->trCollaborationDiagram(title));
       ol.endGroupCollaboration(graph);
-      ol.endParagraph();
+      //ol.endParagraph();
       ol.popGeneratorState();
     }
   }
@@ -604,7 +639,7 @@ void GroupDef::writeFiles(OutputList &ol,const QCString &title)
   // write list of files
   if (fileList->count()>0)
   {
-    ol.startMemberHeader();
+    ol.startMemberHeader("files");
     ol.parseText(title);
     ol.endMemberHeader();
     ol.startMemberList();
@@ -622,11 +657,9 @@ void GroupDef::writeFiles(OutputList &ol,const QCString &title)
       ol.endMemberItem();
       if (!fd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
       {
-        ol.startParagraph();
         ol.startMemberDescription();
         ol.parseDoc(briefFile(),briefLine(),fd,0,fd->briefDescription(),FALSE,FALSE);
         ol.endMemberDescription();
-        ol.endParagraph();
       }
       fd=fileList->next();
     }
@@ -645,7 +678,7 @@ void GroupDef::writeNestedGroups(OutputList &ol,const QCString &title)
   // write list of groups
   if (groupList->count()>0)
   {
-    ol.startMemberHeader();
+    ol.startMemberHeader("groups");
     ol.parseText(title);
     ol.endMemberHeader();
     ol.startMemberList();
@@ -664,11 +697,9 @@ void GroupDef::writeNestedGroups(OutputList &ol,const QCString &title)
       ol.endMemberItem();
       if (!gd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
       {
-        ol.startParagraph();
         ol.startMemberDescription();
         ol.parseDoc(briefFile(),briefLine(),gd,0,gd->briefDescription(),FALSE,FALSE);
         ol.endMemberDescription();
-        ol.endParagraph();
       }
       gd=groupList->next();
     }
@@ -681,7 +712,7 @@ void GroupDef::writeDirs(OutputList &ol,const QCString &title)
   // write list of directories
   if (dirList->count()>0)
   {
-    ol.startMemberHeader();
+    ol.startMemberHeader("dirs");
     ol.parseText(title);
     ol.endMemberHeader();
     ol.startMemberList();
@@ -699,11 +730,9 @@ void GroupDef::writeDirs(OutputList &ol,const QCString &title)
       }
       if (!dd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
       {
-        ol.startParagraph();
         ol.startMemberDescription();
         ol.parseDoc(briefFile(),briefLine(),dd,0,dd->briefDescription(),FALSE,FALSE);
         ol.endMemberDescription();
-        ol.endParagraph();
       }
       dd=dirList->next();
     }
@@ -718,6 +747,11 @@ void GroupDef::writeClasses(OutputList &ol,const QCString &title)
   classSDict->writeDeclaration(ol,0,title,FALSE);
 }
 
+void GroupDef::writeInlineClasses(OutputList &ol)
+{
+  classSDict->writeDocumentation(ol);
+}
+
 void GroupDef::writePageDocumentation(OutputList &ol)
 {
   PageDef *pd=0;
@@ -753,6 +787,7 @@ void GroupDef::writeMemberGroups(OutputList &ol)
   /* write user defined member groups */
   if (memberGroupSDict)
   {
+    memberGroupSDict->sort();
     /* write user defined member groups */
     MemberGroupSDict::Iterator mgli(*memberGroupSDict);
     MemberGroup *mg;
@@ -775,8 +810,10 @@ void GroupDef::endMemberDeclarations(OutputList &ol)
 
 void GroupDef::startMemberDocumentation(OutputList &ol)
 {
+  //printf("** GroupDef::startMemberDocumentation()\n");
   if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
+    ol.pushGeneratorState();
     ol.disable(OutputGenerator::Html);
     Doxygen::suppressDocWarnings = TRUE;
   }
@@ -784,9 +821,10 @@ void GroupDef::startMemberDocumentation(OutputList &ol)
 
 void GroupDef::endMemberDocumentation(OutputList &ol)
 {
+  //printf("** GroupDef::endMemberDocumentation()\n");
   if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
-    ol.enable(OutputGenerator::Html);
+    ol.popGeneratorState();
     Doxygen::suppressDocWarnings = FALSE;
   }
 }
@@ -803,20 +841,70 @@ void GroupDef::writeAuthorSection(OutputList &ol)
   ol.popGeneratorState();
 }
 
-void GroupDef::writeDocumentation(OutputList &ol)
+void GroupDef::writeSummaryLinks(OutputList &ol)
 {
   ol.pushGeneratorState();
-  startFile(ol,getOutputFileBase(),name(),title);
-  startTitle(ol,getOutputFileBase());
-  ol.parseText(title);
-  addGroupListToTitle(ol,this);
-  endTitle(ol,getOutputFileBase(),title);
+  ol.disableAllBut(OutputGenerator::Html);
+  QListIterator<LayoutDocEntry> eli(
+      LayoutDocManager::instance().docEntries(LayoutDocManager::Group));
+  LayoutDocEntry *lde;
+  bool first=TRUE;
+  for (eli.toFirst();(lde=eli.current());++eli)
+  {
+    if ((lde->kind()==LayoutDocEntry::GroupClasses && classSDict->declVisible()) || 
+        (lde->kind()==LayoutDocEntry::GroupNamespaces && namespaceSDict->declVisible()) ||
+        (lde->kind()==LayoutDocEntry::GroupFiles && fileList->count()>0) ||
+        (lde->kind()==LayoutDocEntry::GroupNestedGroups && groupList->count()>0) ||
+        (lde->kind()==LayoutDocEntry::GroupDirs && dirList->count()>0)
+       )
+    {
+      LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
+      QCString label = lde->kind()==LayoutDocEntry::GroupClasses      ? "nested-classes" : 
+                       lde->kind()==LayoutDocEntry::GroupNamespaces   ? "namespaces"     :
+                       lde->kind()==LayoutDocEntry::GroupFiles        ? "files"          :
+                       lde->kind()==LayoutDocEntry::GroupNestedGroups ? "groups"         :
+                       "dirs";
+      writeSummaryLink(ol,label,ls->title,first);
+    }
+    else if (lde->kind()==LayoutDocEntry::MemberDecl)
+    {
+      LayoutDocEntryMemberDecl *lmd = (LayoutDocEntryMemberDecl*)lde;
+      MemberList * ml = getMemberList(lmd->type);
+      if (ml && ml->declVisible())
+      {
+        writeSummaryLink(ol,ml->listTypeAsString(),lmd->title,first);
+      }
+    }
+  }
+  if (!first)
+  {
+    ol.writeString("  </div>\n");
+  }
+  ol.popGeneratorState();
+}
 
-#if 0
-  if (Config_getBool("SEARCHENGINE"))
+void GroupDef::writeDocumentation(OutputList &ol)
+{
+  //static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
+  ol.pushGeneratorState();
+  startFile(ol,getOutputFileBase(),name(),title,HLI_None);
+
+  ol.startHeaderSection();
+  writeSummaryLinks(ol);
+  ol.startTitleHead(getOutputFileBase());
+  ol.pushGeneratorState();
+  ol.disable(OutputGenerator::Man);
+  ol.parseText(title);
+  ol.popGeneratorState();
+  ol.endTitleHead(getOutputFileBase(),title);
+  addGroupListToTitle(ol,this);
+  ol.endHeaderSection();
+  ol.startContents();
+
+  if (Doxygen::searchIndex)
   {
     Doxygen::searchIndex->setCurrentDoc(title,getOutputFileBase());
-    static QRegExp we("[a-zA-Z_][a-zA-Z_0-9]*");
+    static QRegExp we("[a-zA-Z_][-a-zA-Z_0-9]*");
     int i=0,p=0,l=0;
     while ((i=we.match(title,p,&l))!=-1) // foreach word in the title
     {
@@ -824,7 +912,8 @@ void GroupDef::writeDocumentation(OutputList &ol)
       p=i+l;
     }
   }
-#endif
+
+  Doxygen::indexList.addIndexItem(this,0,title);
 
   if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
   {
@@ -856,6 +945,11 @@ void GroupDef::writeDocumentation(OutputList &ol)
           writeClasses(ol,ls->title);
         }
         break; 
+      case LayoutDocEntry::GroupInlineClasses: 
+        {
+          writeInlineClasses(ol);
+        }
+        break;
       case LayoutDocEntry::GroupNamespaces: 
         {
           LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
@@ -925,14 +1019,17 @@ void GroupDef::writeDocumentation(OutputList &ol)
       case LayoutDocEntry::ClassCollaborationGraph:
       case LayoutDocEntry::ClassAllMembersLink:
       case LayoutDocEntry::ClassUsedFiles:
+      case LayoutDocEntry::ClassInlineClasses:
       case LayoutDocEntry::NamespaceNestedNamespaces:
       case LayoutDocEntry::NamespaceClasses:
+      case LayoutDocEntry::NamespaceInlineClasses:
       case LayoutDocEntry::FileClasses:
       case LayoutDocEntry::FileNamespaces:
       case LayoutDocEntry::FileIncludes:
       case LayoutDocEntry::FileIncludeGraph:
       case LayoutDocEntry::FileIncludedByGraph: 
       case LayoutDocEntry::FileSourceLink:
+      case LayoutDocEntry::FileInlineClasses:
       case LayoutDocEntry::DirSubDirs:
       case LayoutDocEntry::DirFiles:
       case LayoutDocEntry::DirGraph:
@@ -945,6 +1042,7 @@ void GroupDef::writeDocumentation(OutputList &ol)
   //---------------------------------------- end flexible part -------------------------------
 
   endFile(ol); 
+
   ol.popGeneratorState();
 
   if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
@@ -1007,7 +1105,7 @@ void GroupDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const
         if (createSubDirs) ol.writeString("../../");
         ol.writeString(md->getOutputFileBase()+Doxygen::htmlFileExtension+"#"+md->anchor());
         ol.writeString("\">");
-        ol.writeString(md->localName());
+        ol.writeString(convertToHtml(md->localName()));
         ol.writeString("</a>");
       }
       ol.writeString("</td></tr>\n");
@@ -1031,8 +1129,11 @@ void addClassToGroups(Entry *root,ClassDef *cd)
     GroupDef *gd=0;
     if (!g->groupname.isEmpty() && (gd=Doxygen::groupSDict->find(g->groupname)))
     {
-      if (gd->addClass(cd)) cd->makePartOfGroup(gd);
-      //printf("Compound %s: in group %s\n",cd->name().data(),s->data());
+      if (gd->addClass(cd)) 
+      {
+        cd->makePartOfGroup(gd);
+      }
+      //printf("Compound %s: in group %s\n",cd->name().data(),gd->groupTitle());
     }
   }
 }
@@ -1111,16 +1212,16 @@ void addMemberToGroups(Entry *root,MemberDef *md)
     GroupDef *gd=0;
     if (!g->groupname.isEmpty() &&
         (gd=Doxygen::groupSDict->find(g->groupname)) &&
-	g->pri >= pri)
+        g->pri >= pri)
     {
       if (fgd && gd!=fgd && g->pri==pri) 
       {
-         warn(root->fileName.data(), root->startLine,
-           "Warning: Member %s found in multiple %s groups! "
-           "The member will be put in group %s, and not in group %s",
-	   md->name().data(), Grouping::getGroupPriName( pri ),
-	   gd->name().data(), fgd->name().data()
-          );
+        warn(root->fileName.data(), root->startLine,
+            "warning: Member %s found in multiple %s groups! "
+            "The member will be put in group %s, and not in group %s",
+            md->name().data(), Grouping::getGroupPriName( pri ),
+            gd->name().data(), fgd->name().data()
+            );
       }
 
       fgd = gd;
@@ -1161,7 +1262,7 @@ void addMemberToGroups(Entry *root,MemberDef *md)
           else if (!root->doc.isEmpty() && md->getGroupHasDocs())
           {
             warn(md->getGroupFileName(),md->getGroupStartLine(),
-                "Warning: Member documentation for %s found several times in %s groups!\n"
+                "warning: Member documentation for %s found several times in %s groups!\n"
                 "%s:%d: The member will remain in group %s, and won't be put into group %s",
                 md->name().data(), Grouping::getGroupPriName( pri ),
                 root->fileName.data(), root->startLine,
@@ -1182,15 +1283,20 @@ void addMemberToGroups(Entry *root,MemberDef *md)
 
     if (insertit)
     {
-      //printf("insertMember found at %s line %d\n",md->getDefFileName().data(),md->getDefLine());
+      //printf("insertMember found at %s line %d: %s: related %s\n",
+      //    md->getDefFileName().data(),md->getDefLine(),
+      //    md->name().data(),root->relates.data());
       bool success = fgd->insertMember(md);
       if (success)
       {
         //printf("insertMember successful\n");
         md->setGroupDef(fgd,pri,root->fileName,root->startLine,
-                        !root->doc.isEmpty());
+            !root->doc.isEmpty());
         ClassDef *cd = md->getClassDefOfAnonymousType();
-        if (cd) cd->setGroupDefForAllMembers(fgd,pri,root->fileName,root->startLine,root->doc.length() != 0);
+        if (cd) 
+        {
+          cd->setGroupDefForAllMembers(fgd,pri,root->fileName,root->startLine,root->doc.length() != 0);
+        }
       }
     }
   }
@@ -1230,8 +1336,10 @@ void GroupDef::addListReferences()
   {
     LockingPtr< QList<ListItemInfo> > xrefItems = xrefListItems();
     addRefItem(xrefItems.pointer(),
+             getOutputFileBase(),
              theTranslator->trGroup(TRUE,TRUE),
-             getOutputFileBase(),name()
+             getOutputFileBase(),name(),
+             0
             );
   }
   MemberGroupSDict::Iterator mgli(*memberGroupSDict);
@@ -1275,14 +1383,23 @@ void GroupDef::addMemberToList(MemberList::ListType lt,MemberDef *md)
   static bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
   static bool sortMemberDocs = Config_getBool("SORT_MEMBER_DOCS");
   MemberList *ml = createMemberList(lt);
-  if (((ml->listType()&MemberList::declarationLists) && sortBriefDocs) ||
-      ((ml->listType()&MemberList::documentationLists) && sortMemberDocs)
-     )
-    ml->inSort(md);
-  else
-    ml->append(md);
+  ml->setNeedsSorting(
+      ((ml->listType()&MemberList::declarationLists) && sortBriefDocs) ||
+      ((ml->listType()&MemberList::documentationLists) && sortMemberDocs));
+  ml->append(md);
 }
 
+void GroupDef::sortMemberLists()
+{
+  MemberList *ml = m_memberLists.first();
+  while (ml)
+  {
+    if (ml->needsSorting()) { ml->sort(); ml->setNeedsSorting(FALSE); }
+    ml = m_memberLists.next();
+  }
+}
+
+
 MemberList *GroupDef::getMemberList(MemberList::ListType lt) const
 {
   GroupDef *that = (GroupDef*)this;
@@ -1305,7 +1422,7 @@ void GroupDef::writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,co
   MemberList * ml = getMemberList(lt);
   if (optimizeVhdl && ml) 
   {
-    VhdlDocGen::writeVhdlDeclarations(ml,ol,this,0,0);
+    VhdlDocGen::writeVhdlDeclarations(ml,ol,this,0,0,0);
     return;
   }
   if (ml) 
