@@ -446,6 +446,25 @@ void HtmlDocVisitor::visit(DocInclude *inc)
       m_t << PREFRAG_END;
       forceStartParagraph(inc);
       break;
+    case DocInclude::Snippet:
+      {
+         forceEndParagraph(inc);
+         m_t << PREFRAG_START;
+         Doxygen::parserManager->getParser(inc->extension())
+                               ->parseCode(m_ci,
+                                           inc->context(),
+                                           extractBlock(inc->text(),inc->blockId()),
+                                           inc->isExample(),
+                                           inc->exampleFile(), 
+                                           0,
+                                           -1,  // startLine
+                                           -1,  // endLine
+                                           TRUE // inlineFragment
+                                          );
+         m_t << PREFRAG_END;
+         forceStartParagraph(inc);
+      }
+      break;
   }
 }
 
@@ -551,6 +570,29 @@ void HtmlDocVisitor::visit(DocSimpleSectSep *)
   m_t << "<dd>" << endl;
 }
 
+void HtmlDocVisitor::visit(DocCite *cite)
+{
+  if (m_hide) return;
+  if (!cite->file().isEmpty()) 
+  {
+    startLink(cite->ref(),cite->file(),cite->relPath(),cite->anchor());
+  }
+  else
+  {
+    m_t << "<b>[";
+  }
+  filter(cite->text());
+  if (!cite->file().isEmpty()) 
+  {
+    endLink();
+  }
+  else
+  {
+    m_t << "]</b>";
+  }
+}
+
+
 //--------------------------------------
 // visitor functions for compound nodes
 //--------------------------------------
@@ -912,6 +954,8 @@ void HtmlDocVisitor::visitPre(DocSimpleSect *s)
       m_t << theTranslator->trPrecondition(); break;
     case DocSimpleSect::Post:
       m_t << theTranslator->trPostcondition(); break;
+    case DocSimpleSect::Copyright:
+      m_t << theTranslator->trCopyright(); break;
     case DocSimpleSect::Invar:
       m_t << theTranslator->trInvariant(); break;
     case DocSimpleSect::Remark:
@@ -1165,7 +1209,12 @@ void HtmlDocVisitor::visitPost(DocInternal *)
 void HtmlDocVisitor::visitPre(DocHRef *href)
 {
   if (m_hide) return;
-  m_t << "<a href=\"" << convertToXML(href->url())  << "\""
+  QCString url = href->url();
+  if (url.left(5)!="http:" && url.left(6)!="https:" && url.left(4)!="ftp:")
+  {
+    url.prepend(href->relPath());
+  }
+  m_t << "<a href=\"" << convertToXML(url)  << "\""
       << htmlAttribsToString(href->attribs()) << ">";
 }
 
@@ -1203,9 +1252,23 @@ void HtmlDocVisitor::visitPre(DocImage *img)
       baseName=baseName.right(baseName.length()-i-1);
     }
     m_t << "<div class=\"image\">" << endl;
-    m_t << "<img src=\"" << img->relPath() << img->name() << "\" alt=\"" 
-        << baseName << "\"" << htmlAttribsToString(img->attribs()) 
-        << "/>" << endl;
+    QCString url = img->url();
+    if (url.isEmpty())
+    {
+      m_t << "<img src=\"" << img->relPath() << img->name() << "\" alt=\"" 
+          << baseName << "\"" << htmlAttribsToString(img->attribs()) 
+          << "/>" << endl;
+    }
+    else
+    {
+      if (url.left(5)!="http:" && url.left(6)!="https:" && url.left(4)!="ftp:")
+      {
+        url.prepend(img->relPath());
+      }
+      m_t << "<img src=\"" << url << "\" " 
+          << htmlAttribsToString(img->attribs())
+          << "/>" << endl;
+    }
     if (img->hasCaption())
     {
       m_t << "<div class=\"caption\">" << endl;
@@ -1364,32 +1427,30 @@ void HtmlDocVisitor::visitPre(DocParamSect *s)
 {
   if (m_hide) return;
   forceEndParagraph(s);
-  m_t << "<dl><dt><b>";
   QCString className;
+  QCString heading;
   switch(s->type())
   {
     case DocParamSect::Param: 
-      m_t << theTranslator->trParameters(); 
+      heading=theTranslator->trParameters(); 
       className="params";
       break;
     case DocParamSect::RetVal: 
-      m_t << theTranslator->trReturnValues(); 
+      heading=theTranslator->trReturnValues(); 
       className="retval";
       break;
     case DocParamSect::Exception: 
-      m_t << theTranslator->trExceptions(); 
+      heading=theTranslator->trExceptions(); 
       className="exception";
       break;
     case DocParamSect::TemplateParam: 
-      /* TODO: add this 
-      m_t << theTranslator->trTemplateParam(); break;
-      */
-      m_t << "Template Parameters"; break;
+      heading="Template Parameters"; break; // TODO: TRANSLATE ME
       className="tparams";
     default:
       ASSERT(0);
   }
-  m_t << ":";
+  m_t << "<dl class=\"" << className << "\"><dt><b>";
+  m_t << heading << ":";
   m_t << "</b></dt><dd>" << endl;
   m_t << "  <table class=\"" << className << "\">" << endl;
 }
@@ -1613,7 +1674,7 @@ void HtmlDocVisitor::startLink(const QCString &ref,const QCString &file,
   if (!file.isEmpty()) m_t << file << Doxygen::htmlFileExtension;
   if (!anchor.isEmpty()) m_t << "#" << anchor;
   m_t << "\"";
-  if (!tooltip.isEmpty()) m_t << " title=\"" << tooltip << "\"";
+  if (!tooltip.isEmpty()) m_t << " title=\"" << substitute(tooltip,"\"","&quot;") << "\"";
   m_t << ">";
 }
 
@@ -1654,7 +1715,8 @@ void HtmlDocVisitor::writeDotFile(const QCString &fn,const QCString &relPath,
   writeDotImageMapFromFile(m_t,fn,outDir,relPath,baseName,context);
 }
 
-void HtmlDocVisitor::writeMscFile(const QCString &fileName,const QCString &relPath,
+void HtmlDocVisitor::writeMscFile(const QCString &fileName,
+                                  const QCString &relPath,
                                   const QCString &context)
 {
   QCString baseName=fileName;
