@@ -38,15 +38,16 @@ class LatexGenerator : public OutputGenerator
     void enable() 
     { if (genStack->top()) active=*genStack->top(); else active=TRUE; }
     void disable() { active=FALSE; }
-    void enableIf(OutputType o)  { if (o==Latex) active=TRUE;  }
-    void disableIf(OutputType o) { if (o==Latex) active=FALSE; }
-    void disableIfNot(OutputType o) { if (o!=Latex) active=FALSE; }
+    void enableIf(OutputType o)  { if (o==Latex) enable();  }
+    void disableIf(OutputType o) { if (o==Latex) disable(); }
+    void disableIfNot(OutputType o) { if (o!=Latex) disable(); }
     bool isEnabled(OutputType o) { return (o==Latex && active); } 
     OutputGenerator *get(OutputType o) { return (o==Latex) ? this : 0; }
 
     void printDoc(DocNode *,const char *);
 
     void startFile(const char *name,const char *manName,const char *title);
+    void writeSearchInfo() {}
     void writeFooter() {}
     void endFile();
     void clearBuffer();
@@ -108,8 +109,6 @@ class LatexGenerator : public OutputGenerator
     void endMemberDocList() {}
     void startMemberList();
     void endMemberList();
-    void startInlineDescription() {}
-    void endInlineDescription() {}
     void startInlineHeader();
     void endInlineHeader();
     void startAnonTypeScope(int);
@@ -143,7 +142,7 @@ class LatexGenerator : public OutputGenerator
     void endDescription();
     void startDescItem();
     void endDescItem();
-    void lineBreak(const char *style=0) { (void)style; t << "\\par\n"; }
+    void lineBreak(const char *style=0);
     void startMemberDoc(const char *,const char *,const char *,const char *,bool);
     void endMemberDoc(bool);
     void startDoxyAnchor(const char *,const char *,const char *,const char *,const char *);
@@ -239,6 +238,15 @@ class LatexGenerator : public OutputGenerator
     void endConstraintDocs();
     void endConstraintList();
 
+    void startMemberDocSimple();
+    void endMemberDocSimple();
+    void startInlineMemberType();
+    void endInlineMemberType();
+    void startInlineMemberName();
+    void endInlineMemberName();
+    void startInlineMemberDoc();
+    void endInlineMemberDoc();
+
     void startFontClass(const char *); // {}
     void endFontClass(); // {}
 
