@@ -3,7 +3,7 @@
  * $Id: layout.cpp,v 1.2 2001/03/19 19:27:41 root Exp $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -255,7 +255,7 @@ class LayoutParser : public QXmlDefaultHandler
           new StartElementHandlerKind(this,LayoutDocEntry::MemberGroups,&LayoutParser::startSimpleEntry));
       m_sHandler.insert("class/memberdecl/nestedclasses", 
           new StartElementHandlerSection(this,LayoutDocEntry::ClassNestedClasses,&LayoutParser::startSectionEntry,
-                                         vhdlOpt ? VhdlDocGen::trVhdlType(VhdlDocGen::ARCHITECTURE,FALSE) :
+                                         vhdlOpt ? VhdlDocGen::trVhdlType(VhdlDocGen::ENTITY,FALSE) :
                                          fortranOpt ? theTranslator->trDataTypes() :
                                          theTranslator->trCompounds() 
                                          ));
@@ -348,6 +348,11 @@ class LayoutParser : public QXmlDefaultHandler
           new EndElementHandler(this,&LayoutParser::endMemberDecl));
       m_sHandler.insert("class/memberdef", 
           new StartElementHandler(this,&LayoutParser::startMemberDef));
+      m_sHandler.insert("class/memberdef/inlineclasses", 
+          new StartElementHandlerSection(this,LayoutDocEntry::ClassInlineClasses,&LayoutParser::startSectionEntry,
+                                         fortranOpt ? theTranslator->trTypeDocumentation() :
+                                         theTranslator->trClassDocumentation() 
+                                         ));
       m_sHandler.insert("class/memberdef/typedefs", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
                                         MemberList::typedefMembers,theTranslator->trMemberTypedefDocumentation()));
@@ -395,13 +400,13 @@ class LayoutParser : public QXmlDefaultHandler
           new StartElementHandler(this,&LayoutParser::startMemberDecl));
       m_sHandler.insert("namespace/memberdecl/nestednamespaces", 
           new StartElementHandlerSection(this,LayoutDocEntry::NamespaceNestedNamespaces,&LayoutParser::startSectionEntry,
-                                         javaOpt ? theTranslator->trPackages() :
+                                         javaOpt || vhdlOpt ? theTranslator->trPackages() :
                                          fortranOpt ? theTranslator->trModules() :
                                          theTranslator->trNamespaces()
                                          ));
       m_sHandler.insert("namespace/memberdecl/classes", 
           new StartElementHandlerSection(this,LayoutDocEntry::NamespaceClasses,&LayoutParser::startSectionEntry,
-                                         vhdlOpt ? VhdlDocGen::trVhdlType(VhdlDocGen::ARCHITECTURE,FALSE) :
+                                         vhdlOpt ? VhdlDocGen::trVhdlType(VhdlDocGen::ENTITY,FALSE) :
                                          fortranOpt ? theTranslator->trDataTypes() :
                                          theTranslator->trCompounds() 
                                          ));
@@ -426,6 +431,11 @@ class LayoutParser : public QXmlDefaultHandler
           new EndElementHandler(this,&LayoutParser::endMemberDecl));
       m_sHandler.insert("namespace/memberdef", 
           new StartElementHandler(this,&LayoutParser::startMemberDef));
+      m_sHandler.insert("namespace/memberdef/inlineclasses", 
+          new StartElementHandlerSection(this,LayoutDocEntry::NamespaceInlineClasses,&LayoutParser::startSectionEntry,
+                                         fortranOpt ? theTranslator->trTypeDocumentation() :
+                                         theTranslator->trClassDocumentation() 
+                                         ));
       m_sHandler.insert("namespace/memberdef/typedefs", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
                                         MemberList::docTypedefMembers,theTranslator->trTypedefDocumentation()));
@@ -470,7 +480,7 @@ class LayoutParser : public QXmlDefaultHandler
           new StartElementHandler(this,&LayoutParser::startMemberDecl));
       m_sHandler.insert("file/memberdecl/classes", 
           new StartElementHandlerSection(this,LayoutDocEntry::FileClasses,&LayoutParser::startSectionEntry,
-                                         vhdlOpt ? VhdlDocGen::trVhdlType(VhdlDocGen::ARCHITECTURE,FALSE) :
+                                         vhdlOpt ? VhdlDocGen::trVhdlType(VhdlDocGen::ENTITY,FALSE) :
                                          fortranOpt ? theTranslator->trDataTypes() :
                                          theTranslator->trCompounds() 
                                          ));
@@ -503,6 +513,11 @@ class LayoutParser : public QXmlDefaultHandler
           new EndElementHandler(this,&LayoutParser::endMemberDecl));
       m_sHandler.insert("file/memberdef", 
           new StartElementHandler(this,&LayoutParser::startMemberDef));
+      m_sHandler.insert("file/memberdef/inlineclasses", 
+          new StartElementHandlerSection(this,LayoutDocEntry::FileInlineClasses,&LayoutParser::startSectionEntry,
+                                         fortranOpt ? theTranslator->trTypeDocumentation() :
+                                         theTranslator->trClassDocumentation() 
+                                         ));
       m_sHandler.insert("file/memberdef/defines", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
                                         MemberList::docDefineMembers,theTranslator->trDefineDocumentation()));
@@ -511,10 +526,12 @@ class LayoutParser : public QXmlDefaultHandler
                                         MemberList::docTypedefMembers,theTranslator->trTypedefDocumentation()));
       m_sHandler.insert("file/memberdef/enums", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
-                                        MemberList::docEnumMembers,theTranslator->trEnumerationTypeDocumentation()));
+                                        MemberList::docEnumMembers,
+                                        theTranslator->trEnumerationTypeDocumentation()));
       m_sHandler.insert("file/memberdef/functions", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
-                                        MemberList::docFuncMembers,theTranslator->trFunctionDocumentation()));
+                                        MemberList::docFuncMembers,
+                                        fortranOpt ? theTranslator->trSubprogramDocumentation() : theTranslator->trFunctionDocumentation()));
       m_sHandler.insert("file/memberdef/variables", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
                                         MemberList::docVarMembers,theTranslator->trVariableDocumentation()));
@@ -541,7 +558,7 @@ class LayoutParser : public QXmlDefaultHandler
           new StartElementHandler(this,&LayoutParser::startMemberDecl));
       m_sHandler.insert("group/memberdecl/classes", 
           new StartElementHandlerSection(this,LayoutDocEntry::GroupClasses,&LayoutParser::startSectionEntry,
-                                         vhdlOpt ? VhdlDocGen::trVhdlType(VhdlDocGen::ARCHITECTURE,FALSE) :
+                                         vhdlOpt ? VhdlDocGen::trVhdlType(VhdlDocGen::ENTITY,FALSE) :
                                          fortranOpt ? theTranslator->trDataTypes() :
                                          theTranslator->trCompounds() 
                                          ));
@@ -612,6 +629,11 @@ class LayoutParser : public QXmlDefaultHandler
           new StartElementHandler(this,&LayoutParser::startMemberDef));
       m_sHandler.insert("group/memberdef/pagedocs", 
           new StartElementHandlerKind(this,LayoutDocEntry::GroupPageDocs,&LayoutParser::startSimpleEntry));
+      m_sHandler.insert("group/memberdef/inlineclasses", 
+          new StartElementHandlerSection(this,LayoutDocEntry::GroupInlineClasses,&LayoutParser::startSectionEntry,
+                                         fortranOpt ? theTranslator->trTypeDocumentation() :
+                                         theTranslator->trClassDocumentation() 
+                                         ));
       m_sHandler.insert("group/memberdef/defines", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
                                         MemberList::docDefineMembers,theTranslator->trDefineDocumentation()));
@@ -759,56 +781,155 @@ class LayoutParser : public QXmlDefaultHandler
       {
         // no MainPage node... add one the first item of the root node...
         new LayoutNavEntry(m_rootNav,LayoutNavEntry::MainPage, TRUE, 
-            Config_getBool("GENERATE_TREEVIEW") ? "main" : "index",
+            /*Config_getBool("GENERATE_TREEVIEW") ? "main" :*/ "index",
             theTranslator->trMainPage(),TRUE);
       }
     }
 
     void startNavEntry(const QXmlAttributes &attrib)
     {
-      bool javaOpt    = Config_getBool("OPTIMIZE_OUTPUT_JAVA");
-      bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
-      bool vhdlOpt    = Config_getBool("OPTIMIZE_OUTPUT_VHDL");  
+      static bool javaOpt    = Config_getBool("OPTIMIZE_OUTPUT_JAVA");
+      static bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
+      static bool vhdlOpt    = Config_getBool("OPTIMIZE_OUTPUT_VHDL");  
+      static bool hasGraphicalHierarchy = Config_getBool("HAVE_DOT") &&
+                                          Config_getBool("GRAPHICAL_HIERARCHY");
+      static bool extractAll = Config_getBool("EXTRACT_ALL");
       static struct NavEntryMap
       {
         const char *typeStr;       // type attribute name in the XML file
         LayoutNavEntry::Kind kind; // corresponding enum name
         QCString mainName;         // default title for an item if it has children
         QCString subName;          // optional name for an item if it is rendered as a child
+        QCString intro;            // introduction text to be put on the index page
         QCString baseFile;         // base name of the file containing the index page
       } mapping[] =
       {
-        { "mainpage",         LayoutNavEntry::MainPage,         theTranslator->trMainPage(),     QCString(), Config_getBool("GENERATE_TREEVIEW") ? "main" : "index" },
-        { "pages",            LayoutNavEntry::Pages,            theTranslator->trRelatedPages(), QCString(), "pages"  },
-        { "modules",          LayoutNavEntry::Modules,          theTranslator->trModules(),      QCString(), "modules" },
-        { "namespaces",       LayoutNavEntry::Namespaces,       javaOpt    ? theTranslator->trPackages() : 
-                                                                fortranOpt ? theTranslator->trModules() : 
-                                                                theTranslator->trNamespaces(),        
-                                                                javaOpt    ? theTranslator->trPackages() :
-                                                                fortranOpt ? theTranslator->trModulesList() :
-                                                                theTranslator->trNamespaceList(), "namespaces" },
-        { "namespacemembers", LayoutNavEntry::NamespaceMembers, javaOpt    ? theTranslator->trPackageMembers() :
-                                                                fortranOpt ? theTranslator->trModulesMembers() :
-                                                                theTranslator->trNamespaceMembers(), QCString(), "namespacemembers" },
-        { "classindex",       LayoutNavEntry::Classes,          fortranOpt ? theTranslator->trDataTypes() :
-                                                                vhdlOpt    ? VhdlDocGen::trDesignUnits() :
-                                                                theTranslator->trCompoundIndex(),
-                                                                QCString(), "classes" },
-        { "classes",          LayoutNavEntry::ClassAnnotated,   fortranOpt ? theTranslator->trCompoundListFortran() :
-                                                                vhdlOpt    ? VhdlDocGen::trDesignUnitList() :
-                                                                theTranslator->trClasses(), 
-                                                                theTranslator->trCompoundList(), "annotated" },
-        { "hierarchy",        LayoutNavEntry::ClassHierarchy,   vhdlOpt    ? VhdlDocGen::trDesignUnitHierarchy() :
-                                                                theTranslator->trClassHierarchy(), QCString(), "hierarchy" },
-        { "classmembers",     LayoutNavEntry::ClassMembers,     fortranOpt ? theTranslator->trCompoundMembersFortran() :
-                                                                vhdlOpt    ? VhdlDocGen::trDesignUnitMembers() :
-                                                                theTranslator->trCompoundMembers(), QCString(), "functions" },
-        { "files",            LayoutNavEntry::Files,            theTranslator->trFile(TRUE,FALSE), 
-                                                                theTranslator->trFileList(), "files" },
-        { "globals",          LayoutNavEntry::FileGlobals,      theTranslator->trFileMembers(), QCString(), "globals" },
-        { "dirs",             LayoutNavEntry::Dirs,             theTranslator->trDirectories(), QCString(), "dirs" },
-        { "examples",         LayoutNavEntry::Examples,         theTranslator->trExamples(), QCString(), "examples" },
-        { 0,                 (LayoutNavEntry::Kind)0,           QCString(), QCString(), QCString() }
+        { "mainpage",
+          LayoutNavEntry::MainPage,
+          theTranslator->trMainPage(),
+          QCString(),
+          QCString(),
+          "index"
+        },
+        { "pages",
+          LayoutNavEntry::Pages,
+          theTranslator->trRelatedPages(),
+          QCString(),
+          theTranslator->trRelatedPagesDescription(),
+          "pages"
+        },
+        { "modules",
+          LayoutNavEntry::Modules,
+          theTranslator->trModules(),
+          QCString(),
+          theTranslator->trModulesDescription(),
+          "modules"
+        },
+        { "namespaces",
+          LayoutNavEntry::Namespaces,
+          javaOpt || vhdlOpt   ? theTranslator->trPackages() : fortranOpt ? theTranslator->trModules() : theTranslator->trNamespaces(),
+          javaOpt || vhdlOpt   ? theTranslator->trPackages() : fortranOpt ? theTranslator->trModulesList() : theTranslator->trNamespaceList(),
+          javaOpt || vhdlOpt   ? theTranslator->trPackageListDescription() : fortranOpt ? theTranslator->trModulesListDescription(extractAll) : theTranslator->trNamespaceListDescription(extractAll),
+          "namespaces"
+        },
+        { "namespacelist",
+          LayoutNavEntry::NamespaceList,
+          javaOpt || vhdlOpt   ? theTranslator->trPackages() : fortranOpt ? theTranslator->trModulesList() : theTranslator->trNamespaceList(),
+          QCString(),
+          javaOpt || vhdlOpt   ? theTranslator->trPackageListDescription() : fortranOpt ? theTranslator->trModulesListDescription(extractAll) : theTranslator->trNamespaceListDescription(extractAll),
+          "namespaces"
+        },
+        { "namespacemembers",
+          LayoutNavEntry::NamespaceMembers,
+          javaOpt || vhdlOpt   ? theTranslator->trPackageMembers() : fortranOpt ? theTranslator->trModulesMembers() : theTranslator->trNamespaceMembers(),
+          QCString(),
+          fortranOpt ? theTranslator->trModulesMemberDescription(extractAll) : theTranslator->trNamespaceMemberDescription(extractAll),
+          "namespacemembers"
+        },
+        { "classindex",
+          LayoutNavEntry::ClassIndex,
+          fortranOpt ? theTranslator->trDataTypes() : vhdlOpt ? VhdlDocGen::trDesignUnits() : theTranslator->trCompoundIndex(),
+          QCString(),
+          QCString(),
+          "classes"
+        },
+        { "classes",
+          LayoutNavEntry::Classes,
+          fortranOpt ? theTranslator->trCompoundListFortran() : vhdlOpt ? VhdlDocGen::trDesignUnitList() : theTranslator->trClasses(),
+          theTranslator->trCompoundList(),
+          fortranOpt ? theTranslator->trCompoundListDescriptionFortran() : vhdlOpt ? VhdlDocGen::trDesignUnitListDescription() : theTranslator->trCompoundListDescription(),
+          "annotated"
+        },
+        { "classlist",
+          LayoutNavEntry::ClassList,
+          fortranOpt ? theTranslator->trCompoundListFortran() : vhdlOpt ? VhdlDocGen::trDesignUnitList() : theTranslator->trCompoundList(),
+          QCString(),
+          fortranOpt ? theTranslator->trCompoundListDescriptionFortran() : vhdlOpt ? VhdlDocGen::trDesignUnitListDescription() : theTranslator->trCompoundListDescription(),
+          "annotated"
+        },
+        { "hierarchy",
+          LayoutNavEntry::ClassHierarchy,
+          vhdlOpt    ? VhdlDocGen::trDesignUnitHierarchy() : theTranslator->trClassHierarchy(),
+          QCString(),
+          theTranslator->trClassHierarchyDescription(),
+          hasGraphicalHierarchy ? "inherits" : "hierarchy"
+        },
+        { "classmembers",
+          LayoutNavEntry::ClassMembers,
+          fortranOpt ? theTranslator->trCompoundMembersFortran() : vhdlOpt ? VhdlDocGen::trDesignUnitMembers() : theTranslator->trCompoundMembers(),
+          QCString(),
+          fortranOpt ? theTranslator->trCompoundMembersDescriptionFortran(extractAll) : theTranslator->trCompoundMembersDescription(extractAll),
+          "functions"
+        },
+        { "files",
+          LayoutNavEntry::Files,
+          theTranslator->trFile(TRUE,FALSE),
+          theTranslator->trFileList(),
+          theTranslator->trFileListDescription(extractAll),
+          "files"
+        },
+        { "filelist",
+          LayoutNavEntry::FileList,
+          theTranslator->trFileList(),
+          QCString(),
+          theTranslator->trFileListDescription(extractAll),
+          "files"
+        },
+        { "globals",
+          LayoutNavEntry::FileGlobals,
+          theTranslator->trFileMembers(),
+          QCString(),
+          theTranslator->trFileMembersDescription(extractAll),
+          "globals"
+        },
+        { "dirs",
+          LayoutNavEntry::Dirs,
+          theTranslator->trDirectories(),
+          QCString(),
+          theTranslator->trDirDescription(),
+          "dirs"
+        },
+        { "examples",
+          LayoutNavEntry::Examples,
+          theTranslator->trExamples(),
+          QCString(),
+          theTranslator->trExamplesDescription(),
+          "examples"
+        },
+        { "user",
+          LayoutNavEntry::User,
+          QCString(),
+          QCString(),
+          QCString(),
+          "user"
+        },
+        { 0, // end of list
+          (LayoutNavEntry::Kind)0,
+          QCString(),
+          QCString(),
+          QCString(),
+          QCString()
+        }
       };
       LayoutNavEntry::Kind kind;
       // find type in the table
@@ -847,8 +968,18 @@ class LayoutParser : public QXmlDefaultHandler
                                       // this is mainly done to get compatible naming with older versions.
         }
       }
+      QCString intro = convertToQCString(attrib.value("intro"));
+      if (intro.isEmpty()) // use default intro text
+      {
+        intro = mapping[i].intro;
+      }
+      QCString url = convertToQCString(attrib.value("url"));
+      if (mapping[i].kind==LayoutNavEntry::User && !url.isEmpty())
+      {
+        baseFile=url;
+      }
       // create new item and make it the new root
-      m_rootNav = new LayoutNavEntry(m_rootNav,kind,kind==LayoutNavEntry::MainPage?TRUE:isVisible,baseFile,title);
+      m_rootNav = new LayoutNavEntry(m_rootNav,kind,kind==LayoutNavEntry::MainPage?TRUE:isVisible,baseFile,title,intro);
     }
 
     void endNavEntry()
@@ -1025,24 +1156,25 @@ class LayoutParser : public QXmlDefaultHandler
 class LayoutErrorHandler : public QXmlErrorHandler
 {
   public:
+    LayoutErrorHandler(const char *fn) : fileName(fn) {}
     bool warning( const QXmlParseException &exception )
     {
-      err("error: at line %d column %d: %s\n",
-          exception.lineNumber(),exception.columnNumber(),
+      err("warning: at line %d column %d of %s: %s\n",
+          exception.lineNumber(),exception.columnNumber(),fileName.data(),
           exception.message().data());
       return FALSE;
     }
     bool error( const QXmlParseException &exception )
     {
-      err("error: at line %d column %d: %s\n",
-          exception.lineNumber(),exception.columnNumber(),
+      err("error: at line %d column %d of %s: %s\n",
+          exception.lineNumber(),exception.columnNumber(),fileName.data(),
           exception.message().data());
       return FALSE;
     }
     bool fatalError( const QXmlParseException &exception )
     {
-      err("error: at line %d column %d: %s\n",
-          exception.lineNumber(),exception.columnNumber(),
+      err("fatal error: at line %d column %d of %s: %s\n",
+          exception.lineNumber(),exception.columnNumber(),fileName.data(),
           exception.message().data());
       return FALSE;
     }
@@ -1050,6 +1182,7 @@ class LayoutErrorHandler : public QXmlErrorHandler
 
   private:
     QString errorMsg;
+    QString fileName;
 };
 
 //---------------------------------------------------------------------------------
@@ -1077,7 +1210,7 @@ LayoutDocManager::LayoutDocManager()
 void LayoutDocManager::init()
 {
   // parse the default layout
-  LayoutErrorHandler errorHandler;
+  LayoutErrorHandler errorHandler( "layout_default.xml" );
   QXmlInputSource source;
   source.setData( layout_default );
   QXmlSimpleReader reader;
@@ -1118,9 +1251,9 @@ void LayoutDocManager::clear(LayoutDocManager::LayoutPart p)
   d->docEntries[(int)p].clear();
 }
 
-void LayoutDocManager::parse(QTextStream &t)
+void LayoutDocManager::parse(QTextStream &t,const char *fileName)
 {
-  LayoutErrorHandler errorHandler;
+  LayoutErrorHandler errorHandler(fileName);
   QXmlInputSource source( t );
   QXmlSimpleReader reader;
   reader.setContentHandler( &LayoutParser::instance() );
