@@ -38,18 +38,20 @@ struct LayoutDocEntry
               AuthorSection,
               
               // Class specific items
-              ClassIncludes,
+              ClassIncludes, ClassInlineClasses,
               ClassInheritanceGraph, ClassNestedClasses,
               ClassCollaborationGraph, ClassAllMembersLink,
               ClassUsedFiles,
 
               // Namespace specific items
               NamespaceNestedNamespaces, NamespaceClasses,
+              NamespaceInlineClasses,
 
               // File specific items
               FileClasses, FileNamespaces, 
               FileIncludes, FileIncludeGraph, 
               FileIncludedByGraph, FileSourceLink,
+              FileInlineClasses,
 
               // Group specific items
               GroupClasses, GroupInlineClasses, GroupNamespaces,
@@ -113,15 +115,19 @@ struct LayoutNavEntry
       Pages,
       Modules, 
       Namespaces, 
+      NamespaceList,
       NamespaceMembers,
-      Classes, 
-      ClassAnnotated, 
+      Classes,
+      ClassList, 
+      ClassIndex, 
       ClassHierarchy, 
       ClassMembers,
       Files, 
+      FileList,
       FileGlobals,
       Dirs, 
-      Examples
+      Examples,
+      User
     };
     LayoutNavEntry(LayoutNavEntry *parent,Kind k,bool vs,const QCString &bf, 
                    const QCString &tl,const QCString &intro,bool prepend=FALSE) 
@@ -173,7 +179,7 @@ class LayoutDocManager
     LayoutNavEntry *rootNavEntry() const;
 
     /** Parses a user provided layout */
-    void parse(QTextStream &t);
+    void parse(QTextStream &t,const char *fileName);
     void init();
   private:
     void addEntry(LayoutPart p,LayoutDocEntry*e);
