@@ -2,7 +2,7 @@
  *
  * $Id: memberlist.h,v 1.19 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -118,6 +118,7 @@ class MemberList : public QList<MemberDef>
     MemberList(ListType lt);
    ~MemberList();
     ListType listType() const { return m_listType; }
+    QCString listTypeAsString() const;
     bool insert(uint index,const MemberDef *md);
     void inSort(const MemberDef *md);
     void append(const MemberDef *md);
@@ -132,22 +133,26 @@ class MemberList : public QList<MemberDef>
     int friendCount() const    { ASSERT(m_numDecMembers!=-1); return m_friendCnt;  }
     int numDecMembers() const  { ASSERT(m_numDecMembers!=-1); return m_numDecMembers; }
     int numDocMembers() const  { ASSERT(m_numDocMembers!=-1); return m_numDocMembers; }
-    void countDecMembers(bool countEnumValues=FALSE);
+    bool needsSorting() const  { return m_needsSorting; }
+    void countDecMembers(bool countEnumValues=FALSE,GroupDef *gd=0);
     void countDocMembers(bool countEnumValues=FALSE);
     void writePlainDeclarations(OutputList &ol,
                ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd);
     void writeDeclarations(OutputList &ol,
                ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd,
-               const char *title,const char *subtitle,bool showEnumValues=FALSE);
+               const char *title,const char *subtitle,bool showEnumValues=FALSE,bool showInline=FALSE);
     void writeDocumentation(OutputList &ol,const char *scopeName,
-               Definition *container,const char *title,bool showEnumValues=FALSE);
+               Definition *container,const char *title,bool showEnumValues=FALSE,bool showInline=FALSE);
+    void writeSimpleDocumentation(OutputList &ol,Definition *container);
     void writeDocumentationPage(OutputList &ol,
                const char *scopeName, Definition *container);
+    bool declVisible() const;
     void addMemberGroup(MemberGroup *mg);
     void setInGroup(bool inGroup) { m_inGroup=inGroup; }
     void setInFile(bool inFile) { m_inFile=inFile; }
     void addListReferences(Definition *def);
     void findSectionsInDocumentation();
+    void setNeedsSorting(bool b);
     MemberGroupList *getMemberGroupList() const { return memberGroupList; }
 
     void marshal(StorageIntf *s);
@@ -168,6 +173,7 @@ class MemberList : public QList<MemberDef>
     bool m_inGroup; // is this list part of a group definition
     bool m_inFile;  // is this list part of a file definition
     ListType m_listType;
+    bool m_needsSorting;
 };
 
 class MemberListIterator : public QListIterator<MemberDef>
