@@ -2,7 +2,7 @@
  *
  * $Id: namespacedef.h,v 1.18 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -43,11 +43,10 @@ class NamespaceDef : public Definition
    ~NamespaceDef();
     DefType definitionType() const { return TypeNamespace; }
     QCString getOutputFileBase() const;
+    QCString anchor() const { return QCString(); }
     void insertUsedFile(const char *fname);
     
-    void writeDetailedDocumentation(OutputList &ol);
     void writeDocumentation(OutputList &ol);
-    void writeMemberDocumentation(OutputList &ol);
     void writeMemberPages(OutputList &ol);
     void writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const;
 
@@ -69,6 +68,7 @@ class NamespaceDef : public Definition
     void addMembersToMemberGroup();
     void distributeMemberGroupDocumentation();
     void findSectionsInDocumentation();
+    void sortMemberLists();
 
     virtual Definition *findInnerCompound(const char *name);
     void addInnerCompound(Definition *d);
@@ -76,6 +76,7 @@ class NamespaceDef : public Definition
     
     MemberList *getMemberList(MemberList::ListType lt) const;
     const QList<MemberList> &getMemberLists() const { return m_memberLists; }
+    MemberDef    *getMemberByName(const QCString &) const;
 
     /*! Returns the user defined member groups */
     MemberGroupSDict *getMemberGroupSDict() const { return memberGroupSDict; }
@@ -93,6 +94,18 @@ class NamespaceDef : public Definition
     void addMemberToList(MemberList::ListType lt,MemberDef *md);
     void writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,const QCString &title);
     void writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,const QCString &title);
+    void writeDetailedDescription(OutputList &ol,const QCString &title);
+    void writeBriefDescription(OutputList &ol);
+    void startMemberDeclarations(OutputList &ol);
+    void endMemberDeclarations(OutputList &ol);
+    void writeClassDeclarations(OutputList &ol,const QCString &title);
+    void writeInlineClasses(OutputList &ol);
+    void writeNamespaceDeclarations(OutputList &ol,const QCString &title);
+    void writeMemberGroups(OutputList &ol);
+    void writeAuthorSection(OutputList &ol);
+    void startMemberDocumentation(OutputList &ol);
+    void endMemberDocumentation(OutputList &ol);
+    void writeSummaryLinks(OutputList &ol);
 
     QCString              fileName;
     QStrList              files;
@@ -101,7 +114,7 @@ class NamespaceDef : public Definition
     SDict<Definition>    *usingDeclList;
     SDict<Definition>    *m_innerCompounds;
 
-    //MemberList           *allMemberList;
+    MemberSDict          *m_allMembersDict;
     QList<MemberList>     m_memberLists;
     MemberGroupSDict     *memberGroupSDict;
     ClassSDict           *classSDict;
@@ -146,7 +159,8 @@ class NamespaceSDict : public SDict<NamespaceDef>
                     ((NamespaceDef *)item2)->name()
                    );
     }
-    void writeDeclaration(OutputList &ol,bool localName=FALSE);
+    void writeDeclaration(OutputList &ol,const char *title,bool localName=FALSE);
+    bool declVisible() const;
 };
 
 
