@@ -301,6 +301,7 @@ class OutputGenerator : public BaseOutputDocInterface
     ///////////////////////////////////////////////////////////////
     virtual void startFile(const char *name,const char *manName,
                            const char *title) = 0;
+    virtual void writeSearchInfo() = 0;
     virtual void writeFooter() = 0;
     virtual void endFile() = 0;
     virtual void startIndexSection(IndexSections) = 0;
@@ -335,8 +336,6 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endMemberDocList() = 0;
     virtual void startMemberList() = 0;
     virtual void endMemberList() = 0;
-    virtual void startInlineDescription() = 0;
-    virtual void endInlineDescription() = 0;
     virtual void startInlineHeader() = 0;
     virtual void endInlineHeader() = 0;
     virtual void startAnonTypeScope(int) = 0;
@@ -411,6 +410,15 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endConstraintDocs() = 0;
     virtual void endConstraintList() = 0;
 
+    virtual void startMemberDocSimple() = 0;
+    virtual void endMemberDocSimple() = 0;
+    virtual void startInlineMemberType() = 0;
+    virtual void endInlineMemberType() = 0;
+    virtual void startInlineMemberName() = 0;
+    virtual void endInlineMemberName() = 0;
+    virtual void startInlineMemberDoc() = 0;
+    virtual void endInlineMemberDoc() = 0;
+
   protected:
     FTextStream t;
     QFile *file;
