@@ -2,7 +2,7 @@
  *
  * $Id:$
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -29,35 +29,39 @@ class PageDef : public Definition
     DefType definitionType() const { return TypePage; }
     bool isLinkableInProject() const 
     { 
-      return hasDocumentation() && !isReference();
+      return /*hasDocumentation() &&*/ !isReference();
     }
     bool isLinkable() const 
     {
       return isLinkableInProject() || isReference();
     } 
-    void addSubPage(PageDef *def);
     void writeDocumentation(OutputList &ol);
 
     // functions to get a uniform interface with Definitions
     QCString getOutputFileBase() const;
+    QCString anchor() const { return QCString(); }
     void findSectionsInDocumentation();
     QCString title() const { return m_title; }
     GroupDef *  getGroupDef() const;
-    PageSDict * getSubPages() const { return subPageDict; }
+    PageSDict * getSubPages() const { return m_subPageDict; }
     void setFileName(const char *name) { m_fileName = name; }
     void addInnerCompound(Definition *d);
     bool visibleInIndex() const;
     bool documentedPage() const;
     bool hasSubPages() const;
-    void setPageScope(Definition *d){ pageScope = d; }
-    Definition *getPageScope() const { return pageScope; }
+    bool hasParentPage() const;
+    void setPageScope(Definition *d){ m_pageScope = d; }
+    Definition *getPageScope() const { return m_pageScope; }
 
   private:
+    void setNestingLevel(int l);
+    void writePageDocumentation(OutputList &ol);
     QCString m_fileName;
     QCString m_title;
     GroupDef *m_inGroup;
-    PageSDict *subPageDict;                 // list of pages in the group
-    Definition *pageScope;
+    PageSDict *m_subPageDict;                 // list of pages in the group
+    Definition *m_pageScope;
+    int m_nestingLevel;
 };
 
 class PageSDict : public SDict<PageDef>
