@@ -3,7 +3,7 @@
  *
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  * Authors: Dimitri van Heesch, Miguel Lobo.
  *
  * Permission to use, copy, modify, and distribute this software and its
@@ -297,6 +297,7 @@ public:
   void visit(DocFormula *);
   void visit(DocIndexEntry *);
   void visit(DocSimpleSectSep *);
+  void visit(DocCite *);
 
   //--------------------------------------
   // visitor functions for compound nodes
@@ -350,6 +351,8 @@ public:
   void visitPost(DocImage *);
   void visitPre(DocDotFile *);
   void visitPost(DocDotFile *);
+  void visitPre(DocMscFile *);
+  void visitPost(DocMscFile *);
   void visitPre(DocLink *);
   void visitPost(DocLink *);
   void visitPre(DocRef *);
@@ -530,6 +533,7 @@ void PerlModDocVisitor::visit(DocSymbol *sy)
     case DocSymbol::Amp:     c = '&'; break;
     case DocSymbol::Dollar:  c = '$'; break;
     case DocSymbol::Hash:    c = '#'; break;
+    case DocSymbol::DoubleColon: s = "::"; break;
     case DocSymbol::Percent: c = '%'; break;
     case DocSymbol::Quot:    c = '"'; break;
     case DocSymbol::Lsquo:   s = "\\\'"; break;
@@ -679,6 +683,7 @@ void PerlModDocVisitor::visit(DocInclude *inc)
   case DocInclude::DontInclude:	return;
   case DocInclude::HtmlInclude:	type = "htmlonly"; break;
   case DocInclude::VerbInclude:	type = "preformatted"; break;
+  case DocInclude::Snippet: return;
   }
   openItem(type);
   m_output.addFieldQuotedString("content", inc->text());
@@ -734,6 +739,14 @@ void PerlModDocVisitor::visit(DocSimpleSectSep *)
 {
 }
 
+void PerlModDocVisitor::visit(DocCite *cite)
+{
+  openItem("cite");
+  m_output.addFieldQuotedString("text", cite->text());
+  closeItem();
+}
+
+
 //--------------------------------------
 // visitor functions for compound nodes
 //--------------------------------------
@@ -805,6 +818,7 @@ void PerlModDocVisitor::visitPre(DocSimpleSect *s)
   case DocSimpleSect::Warning:		type = "warning"; break;
   case DocSimpleSect::Pre:		type = "pre"; break;
   case DocSimpleSect::Post:		type = "post"; break;
+  case DocSimpleSect::Copyright:	type = "copyright"; break;
   case DocSimpleSect::Invar:		type = "invariant"; break;
   case DocSimpleSect::Remark:		type = "remark"; break;
   case DocSimpleSect::Attention:	type = "attention"; break;
@@ -1094,6 +1108,20 @@ void PerlModDocVisitor::visitPost(DocDotFile *)
   m_output.add("</dotfile>");
 #endif
 }
+void PerlModDocVisitor::visitPre(DocMscFile *)
+{
+#if 0
+  m_output.add("<mscfile name=\""); m_output.add(df->file()); m_output.add("\">");
+#endif
+}
+
+void PerlModDocVisitor::visitPost(DocMscFile *)
+{
+#if 0
+  m_output.add("<mscfile>");
+#endif
+}
+
 
 void PerlModDocVisitor::visitPre(DocLink *lnk)
 {
@@ -1675,7 +1703,7 @@ void PerlModGenerator::generatePerlModForClass(ClassDef *cd)
     m_output.closeList();
   }
 
-  ClassSDict *cl = cd->getInnerClasses();
+  ClassSDict *cl = cd->getClassSDict();
   if (cl)
   {
     m_output.openList("inner");
