@@ -2,7 +2,7 @@
  *
  * $Id: pre.h,v 1.10 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -20,14 +20,14 @@
 
 #include "qtbc.h"
 #include <stdio.h>
-//#include <qfile.h>
+#include "define.h"
 
 class BufStr;
 
 void initPreprocessor();
 void cleanUpPreprocessor();
 void addSearchDir(const char *dir);
-void preprocessFile(const char *fileName,BufStr &output);
+void preprocessFile(const char *fileName,BufStr &input,BufStr &output);
 void preFreeScanner();
 
 #endif
