@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -184,6 +184,7 @@ class PrintDocVisitor : public DocVisitor
         case DocInclude::DontInclude: printf("dontinclude"); break;
         case DocInclude::HtmlInclude: printf("htmlinclude"); break;
         case DocInclude::VerbInclude: printf("verbinclude"); break;
+        case DocInclude::Snippet: printf("snippet"); break;
       }
       printf("\"/>");
     }
@@ -215,6 +216,15 @@ class PrintDocVisitor : public DocVisitor
       indent_leaf();
       printf("<simplesectsep/>");
     }
+    void visit(DocCite *cite)
+    {
+      indent_leaf();
+      printf("<cite ref=\"%s\" file=\"%s\" "
+             "anchor=\"%s\" text=\"%s\""
+             "/>\n",
+             cite->ref().data(),cite->file().data(),cite->anchor().data(),
+             cite->text().data());
+    }
 
     //--------------------------------------
     
@@ -289,6 +299,7 @@ class PrintDocVisitor : public DocVisitor
 	case DocSimpleSect::Warning: printf("warning"); break;
 	case DocSimpleSect::Pre: printf("pre"); break;
 	case DocSimpleSect::Post: printf("post"); break;
+	case DocSimpleSect::Copyright: printf("copyright"); break;
 	case DocSimpleSect::Invar: printf("invar"); break;
 	case DocSimpleSect::Remark: printf("remark"); break;
 	case DocSimpleSect::Attention: printf("attention"); break;
