@@ -3,7 +3,7 @@
  * $Id: sortdict.h,v 1.3 2001/03/19 19:27:41 root Exp $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -207,6 +207,18 @@ class SDict
 #endif
     }
 
+    void insertAt(int i,const char *key,const T *d)
+    {
+      m_list->insert(i,d);
+      m_dict->insert(key,d);
+#if AUTORESIZE
+      if (m_dict->size()>SDict_primes[m_sizeIndex])
+      {
+        m_dict->resize(SDict_primes[++m_sizeIndex]);
+      }
+#endif
+    }
+
     /*! Indicates whether or not the dictionary owns its elements */
     void setAutoDelete(bool val)
     {
@@ -230,6 +242,12 @@ class SDict
     {
       return m_dict->find(key);
     }
+    int findAt(const QCString &key)
+    {
+      T *item = find(key);
+      if (item==0) return -1;
+      return m_list->find(item);
+    }
 
     /*! Equavalent to find(). */
     T *operator[](const char *key) const
