@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -75,7 +75,6 @@ class TranslatorNorwegian : public TranslatorAdapter_1_4_6
     {
       return
         "\\usepackage[norwegian]{babel}\n"
-        "\\usepackage[latin1]{inputenc}\n"
         "\\usepackage[T1]{fontenc}\n";
     }
 
@@ -1058,6 +1057,8 @@ class TranslatorNorwegian : public TranslatorAdapter_1_4_6
         "class Undocumented { };\n\n" 
         "/*! Klasse med public-arv */\n" 
         "class PublicBase : public Truncated { };\n\n"
+        "/*! A template class */\n"
+        "template<class T> class Templ { };\n\n"
         "/*! Klasse med protected-arv */\n"
         "class ProtectedBase { };\n\n"
         "/*! Klasse med private-arv */\n"
@@ -1068,7 +1069,7 @@ class TranslatorNorwegian : public TranslatorAdapter_1_4_6
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
         "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
