@@ -2,7 +2,7 @@
  *
  * $Id: translator_si.h,v 1.1 2000/07/22 17:04:41 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -37,15 +37,15 @@ class TranslatorSlovene : public TranslatorAdapter_1_4_6
      */
     QCString latexLanguageSupportCommand()
     {
-      return "\\usepackage[slovene]{babel} \n\\usepackage[latin2]{inputenc} \n\\usepackage[T1]{fontenc}\n";
+      return "\\usepackage[slovene]{babel}\n\\usepackage[T1]{fontenc}\n";
     }
     QCString idLanguageCharset()
     { 
-#ifdef _WIN32
+//#ifdef _WIN32
       return "windows-1250"; 
-#else
-      return "iso-8859-2"; 
-#endif
+//#else
+//      return "iso-8859-2"; 
+//#endif
     }
     QCString trRelatedFunctions()
     { return "Povezane funkcije"; }
@@ -684,6 +684,8 @@ class TranslatorSlovene : public TranslatorAdapter_1_4_6
         "class Undocumented { };\n\n"
         "/*! Razred, ki ga dedujemo s pomoèjo javnega dedovanja */\n"
         "class PublicBase : public Truncated { };\n\n"
+        "/*! A template class */\n"
+        "template<class T> class Templ { };\n\n"
         "/*! Razred, ki ga dedujemo s pomoèjo za¹èitenega dedovanja */\n"
         "class ProtectedBase { };\n\n"
         "/*! Razred, ki ga dedujemo s pomoèjo skritega dedovanja */\n"
@@ -694,7 +696,8 @@ class TranslatorSlovene : public TranslatorAdapter_1_4_6
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
+        "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
         "    Used *m_usedClass;\n"
