@@ -1,7 +1,4 @@
 /******************************************************************************
- *
- * $Id: xml.cpp,v 1.2 2001/01/01 10:15:18 root Exp $
- *
  *
  * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
@@ -203,7 +200,7 @@ class TextGeneratorXMLImpl : public TextGeneratorIntf
     {
       writeXMLString(m_t,s); 
     }
-    void writeBreak() const {}
+    void writeBreak(int) const {}
     void writeLink(const char *extRef,const char *file,
                    const char *anchor,const char *text
                   ) const
@@ -498,12 +495,18 @@ void writeXMLCodeBlock(FTextStream &t,FileDef *fd)
   ParserInterface *pIntf=Doxygen::parserManager->getParser(fd->getDefFileExtension());
   pIntf->resetCodeParserState();
   XMLCodeGenerator *xmlGen = new XMLCodeGenerator(t);
-  pIntf->parseCode(*xmlGen,
-                0,
+  pIntf->parseCode(*xmlGen,  // codeOutIntf
+                0,           // scopeName
                 fileToString(fd->absFilePath(),Config_getBool("FILTER_SOURCE_FILES")),
-                FALSE,
-                0,
-                fd);
+                FALSE,       // isExampleBlock
+                0,           // exampleName
+                fd,          // fileDef
+                -1,          // startLine
+                -1,          // endLine
+                FALSE,       // inlineFragement
+                0,           // memberDef
+                TRUE         // showLineNumbers
+                );
   xmlGen->finish();
   delete xmlGen;
 }
@@ -514,7 +517,7 @@ static void writeMemberReference(FTextStream &t,Definition *def,MemberDef *rmd,c
   QCString name = rmd->name();
   if (!scope.isEmpty() && scope!=def->name())
   {
-    name.prepend(scope+"::");
+    name.prepend(scope+getLanguageSpecificSeparator(rmd->getLanguage()));
   }
   t << "        <" << tagName << " refid=\"";
   t << rmd->getOutputFileBase() << "_1" << rmd->anchor() << "\"";
@@ -546,20 +549,21 @@ static void stripQualifiers(QCString &typeStr)
 
 static QCString classOutputFileBase(ClassDef *cd)
 {
-  static bool inlineGroupedClasses = Config_getBool("INLINE_GROUPED_CLASSES");
-  if (inlineGroupedClasses && cd->partOfGroups()!=0) 
-    return cd->getXmlOutputFileBase();
-  else 
-    return cd->getOutputFileBase();
+  //static bool inlineGroupedClasses = Config_getBool("INLINE_GROUPED_CLASSES");
+  //if (inlineGroupedClasses && cd->partOfGroups()!=0) 
+  return cd->getOutputFileBase();
+  //else 
+  //  return cd->getOutputFileBase();
 }
 
 static QCString memberOutputFileBase(MemberDef *md)
 {
-  static bool inlineGroupedClasses = Config_getBool("INLINE_GROUPED_CLASSES");
-  if (inlineGroupedClasses && md->getClassDef() && md->getClassDef()->partOfGroups()!=0) 
-    return md->getClassDef()->getXmlOutputFileBase();
-  else 
-    return md->getOutputFileBase();
+  //static bool inlineGroupedClasses = Config_getBool("INLINE_GROUPED_CLASSES");
+  //if (inlineGroupedClasses && md->getClassDef() && md->getClassDef()->partOfGroups()!=0) 
+  //  return md->getClassDef()->getXmlOutputFileBase();
+  //else 
+  //  return md->getOutputFileBase();
+  return md->getOutputFileBase();
 }
 
 
@@ -1095,7 +1099,7 @@ static void writeInnerClasses(const ClassSDict *cl,FTextStream &t)
     {
       if (!cd->isHidden() && cd->name().find('@')==-1) // skip anonymous scopes
       {
-        t << "    <innerclass refid=\"" << cd->getOutputFileBase()
+        t << "    <innerclass refid=\"" << classOutputFileBase(cd)
           << "\" prot=\"";
         switch(cd->protection())
         {
@@ -1330,7 +1334,7 @@ static void generateXMLForClass(ClassDef *cd,FTextStream &ti)
     }
   }
 
-  writeInnerClasses(cd->getInnerClasses(),t);
+  writeInnerClasses(cd->getClassSDict(),t);
 
   writeTemplateList(cd,t);
   if (cd->getMemberGroupSDict())
